@@ -1,8 +1,10 @@
 import os
 import socket
 from pathlib import Path
+from logzero import logger
 from ssh2.session import Session as ssh2_Session
 from ssh2 import sftp as ssh2_sftp
+from broker.helpers import simple_retry, translate_timeout
 
 SESSIONS = {}
 
@@ -35,7 +37,7 @@ class Session:
         host = kwargs.get("hostname", "localhost")
         user = kwargs.get("username", "root")
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        sock.connect((host, kwargs.get("port", 22)))
+        simple_retry(sock.connect, [(host, kwargs.get("port", 22))])
         self.session = ssh2_Session()
         self.session.handshake(sock)
         if kwargs.get("password"):
@@ -51,7 +53,10 @@ class Session:
         size, data = channel.read()
         results = ""
         while size > 0:
-            results += data.decode("utf-8")
+            try:
+                results += data.decode("utf-8")
+            except UnicodeDecodeError as err:
+                logger.error(f"Skipping data chunk due to {err}\nReceived: {data}")
             size, data = channel.read()
         return Result(
             stdout=results,
@@ -61,7 +66,7 @@ class Session:
 
     def run(self, command, timeout=0):
         """run a command on the host and return the results"""
-        self.session.set_timeout(timeout)
+        self.session.set_timeout(translate_timeout(timeout))
         channel = self.session.open_session()
         channel.execute(
             command,
